==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/DefaultSubscriptions.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.subscriptions.Subscription;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of subscriptions.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultSubscriptions extends InnerModelObject implements Subscriptions {
    protected List<Subscription> subscription;

    @Override
    public List<Subscription> subscription() {
        return subscription;
    }

    @Override
    public void subscription(List<Subscription> subscription) {
        this.subscription = subscription;
    }

    @Override
    public void addToSubscription(Subscription addTo) {
        if (subscription == null) {
            subscription = new ArrayList<>();
        }
        subscription.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(subscription);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultSubscriptions) {
            DefaultSubscriptions other = (DefaultSubscriptions) obj;
            return
                Objects.equals(subscription, other.subscription);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("subscription=" + subscription)
            .toString();
    }


    /**
     * Creates an instance of defaultSubscriptions.
     */
    public DefaultSubscriptions() {
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/DefaultSubscriptions.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription;

import java.util.ArrayList;
import java.util.List;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.subscriptions.Subscription;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of subscriptions.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultSubscriptions extends InnerModelObject implements Subscriptions {
    protected List<Subscription> subscription;

    @Override
    public List<Subscription> subscription() {
        return subscription;
    }

    @Override
    public void subscription(List<Subscription> subscription) {
        this.subscription = subscription;
    }

    @Override
    public void addToSubscription(Subscription addTo) {
        if (subscription == null) {
            subscription = new ArrayList<>();
        }
        subscription.add(addTo);
    }


    @Override
    public int hashCode() {
        return Objects.hash(subscription);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultSubscriptions) {
            DefaultSubscriptions other = (DefaultSubscriptions) obj;
            return
                Objects.deepEquals(subscription, other.subscription);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("subscription=" + subscription)
            .toString();
    }


    /**
     * Creates an instance of defaultSubscriptions.
     */
    public DefaultSubscriptions() {
    }

}
